@@ -55,7 +55,7 @@ static gchar *DEFAULT_TEXT[] = { "cpu", "mem", "swap" };
 static gchar *DEFAULT_COLOR[] = { "#0000c0", "#00c000", "#f0f000" };
 static gchar *DEFAULT_COMMAND_TEXT = "xfce4-taskmanager";
 
-#define UPDATE_TIMEOUT 250
+#define UPDATE_TIMEOUT 500
 #define UPDATE_TIMEOUT_SECONDS 1
 
 #define BORDER 8
@@ -103,7 +103,6 @@ typedef struct
     XfcePanelPlugin   *plugin;
     GtkWidget         *ebox;
     GtkWidget         *box;
-    GtkWidget         *menu_item;
     guint             timeout, timeout_seconds;
     gboolean          use_timeout_seconds;
     guint             timeout_id;
@@ -329,9 +328,7 @@ monitor_control_new(XfcePanelPlugin *plugin)
 {
     int count;
     t_global_monitor *global;
-    GtkWidget* image;
-    GtkWidget *label, *box;
-    
+
     global = g_new(t_global_monitor, 1);
 #ifdef HAVE_UPOWER_GLIB
     global->upower = up_client_new();
@@ -345,21 +342,11 @@ monitor_control_new(XfcePanelPlugin *plugin)
     gtk_widget_show(global->ebox);
     global->box = NULL;
 
-    global->command.enabled = FALSE;
+    global->command.enabled = TRUE;
     global->command.command_text = g_strdup(DEFAULT_COMMAND_TEXT);
 
-    box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-    label = gtk_label_new_with_mnemonic (_("Run _System Monitor"));
-    global->menu_item = gtk_menu_item_new();
-    image = gtk_image_new_from_icon_name("utilities-system-monitor",
-                                                    GTK_ICON_SIZE_MENU);
-    gtk_container_add (GTK_CONTAINER (box), image);
-    gtk_container_add (GTK_CONTAINER (box), label);
-    gtk_container_add (GTK_CONTAINER (global->menu_item), box);
-    gtk_widget_show_all (global->menu_item);
-
     xfce_panel_plugin_add_action_widget (plugin, global->ebox);
-    
+
     for(count = 0; count < 3; count++)
     {
         global->monitor[count] = g_new(t_monitor, 1);
@@ -377,10 +364,10 @@ monitor_control_new(XfcePanelPlugin *plugin)
         global->monitor[count]->history[3] = 0;
 
     }
-    
+
     global->uptime = g_new(t_uptime_monitor, 1);
     global->uptime->enabled = TRUE;
-    
+
     return global;
 }
 
@@ -514,26 +501,26 @@ monitor_read_config(XfcePanelPlugin *plugin, t_global_monitor *global)
     const char *value;
     char *file;
     XfceRc *rc;
-    
+
     if (!(file = xfce_panel_plugin_lookup_rc_file (plugin)))
         return;
-    
+
     rc = xfce_rc_simple_open (file, TRUE);
     g_free (file);
 
     if (!rc)
         return;
-    
+
     if (xfce_rc_has_group (rc, "Main"))
     {
         xfce_rc_set_group (rc, "Main");
         global->timeout = xfce_rc_read_int_entry (rc, "Timeout", global->timeout);
+        if (global->timeout < 500)
+            global->timeout = 500;
         global->timeout_seconds = xfce_rc_read_int_entry (
                 rc, "Timeout_Seconds", global->timeout_seconds);
-        global->use_timeout_seconds = xfce_rc_read_bool_entry (
-                rc, "Use_Timeout_Seconds", global->use_timeout_seconds);
-        global->command.enabled = xfce_rc_read_bool_entry (
-                rc, "Use_Click_Command", global->command.enabled);
+        if (global->timeout_seconds > 0)
+            global->use_timeout_seconds = TRUE;
         value = xfce_rc_read_entry (
                 rc, "Click_Command", NULL);
         if (value && *value)
@@ -541,6 +528,8 @@ monitor_read_config(XfcePanelPlugin *plugin, t_global_monitor *global)
             if (global->command.command_text)
                 g_free(global->command.command_text);
             global->command.command_text = g_strdup(value);
+            if (strlen(value) > 0)
+                global->command.enabled = TRUE;
         }
     }
 
@@ -549,13 +538,13 @@ monitor_read_config(XfcePanelPlugin *plugin, t_global_monitor *global)
         if (xfce_rc_has_group (rc, MONITOR_ROOT[count]))
         {
             xfce_rc_set_group (rc, MONITOR_ROOT[count]);
-            
-            global->monitor[count]->options.enabled = 
+
+            global->monitor[count]->options.enabled =
                 xfce_rc_read_bool_entry (rc, "Enabled", TRUE);
 
-            global->monitor[count]->options.use_label = 
+            global->monitor[count]->options.use_label =
                 xfce_rc_read_bool_entry (rc, "Use_Label", TRUE);
-            
+
             if ((value = xfce_rc_read_entry (rc, "Color", NULL)))
             {
                 gdk_rgba_parse(&global->monitor[count]->options.color,
@@ -572,8 +561,8 @@ monitor_read_config(XfcePanelPlugin *plugin, t_global_monitor *global)
         if (xfce_rc_has_group (rc, MONITOR_ROOT[3]))
         {
             xfce_rc_set_group (rc, MONITOR_ROOT[3]);
-            
-            global->uptime->enabled = 
+
+            global->uptime->enabled =
                 xfce_rc_read_bool_entry (rc, "Enabled", TRUE);
         }
     }
@@ -590,7 +579,7 @@ monitor_write_config(XfcePanelPlugin *plugin, t_global_monitor *global)
 
     if (!(file = xfce_panel_plugin_save_location (plugin, TRUE)))
         return;
-    
+
     rc = xfce_rc_simple_open (file, FALSE);
     g_free (file);
 
@@ -600,24 +589,21 @@ monitor_write_config(XfcePanelPlugin *plugin, t_global_monitor *global)
     xfce_rc_set_group (rc, "Main");
     xfce_rc_write_int_entry (rc, "Timeout", global->timeout);
     xfce_rc_write_int_entry (rc, "Timeout_Seconds", global->timeout_seconds);
-    xfce_rc_write_bool_entry (rc, "Use_Timeout_Seconds",
-                              global->use_timeout_seconds);
-    xfce_rc_write_bool_entry (rc, "Use_Click_Command", global->command.enabled);
     xfce_rc_write_entry (rc, "Click_Command", global->command.command_text);
 
     for(count = 0; count < 3; count++)
     {
         xfce_rc_set_group (rc, MONITOR_ROOT[count]);
 
-        xfce_rc_write_bool_entry (rc, "Enabled", 
+        xfce_rc_write_bool_entry (rc, "Enabled",
                 global->monitor[count]->options.enabled);
-        
-        xfce_rc_write_bool_entry (rc, "Use_Label", 
+
+        xfce_rc_write_bool_entry (rc, "Use_Label",
                 global->monitor[count]->options.use_label);
 
         xfce_rc_write_entry (rc, "Color", gdk_rgba_to_string(&global->monitor[count]->options.color));
 
-        xfce_rc_write_entry (rc, "Text", 
+        xfce_rc_write_entry (rc, "Text",
             global->monitor[count]->options.label_text ?
                 global->monitor[count]->options.label_text : "");
     }
@@ -638,7 +624,7 @@ monitor_set_size(XfcePanelPlugin *plugin, int size, t_global_monitor *global)
     gtk_container_set_border_width (GTK_CONTAINER (global->ebox), (size > 26 ? 2 : 1));
     for(count = 0; count < 3; count++)
     {
-        if (xfce_panel_plugin_get_orientation (plugin) == 
+        if (xfce_panel_plugin_get_orientation (plugin) ==
                 GTK_ORIENTATION_HORIZONTAL)
         {
             gtk_widget_set_size_request(GTK_WIDGET(global->monitor[count]->status),
@@ -650,7 +636,7 @@ monitor_set_size(XfcePanelPlugin *plugin, int size, t_global_monitor *global)
                                         -1, 8);
         }
     }
-    
+
     setup_monitor(global);
 
     return TRUE;
@@ -691,27 +677,15 @@ static void
 entry_changed_cb(GtkEntry *entry, t_global_monitor *global)
 {
     gchar** charvar = (gchar**)g_object_get_data (G_OBJECT(entry), "charvar");
+    gboolean** use_label = (gboolean**)g_object_get_data (G_OBJECT(entry), "boolvar");
     g_free(*charvar);
+    if (gtk_entry_get_text_length (entry) == 0)
+        *use_label = (gboolean *) FALSE;
+    else
+        *use_label = (gboolean *) TRUE;
     *charvar = g_strdup(gtk_entry_get_text(GTK_ENTRY(entry)));
-    setup_monitor(global);
-}
 
-static void
-check_button_cb(GtkToggleButton *check_button, t_global_monitor *global)
-{
-    gboolean oldstate;
-    gboolean* boolvar;
-    gpointer sensitive_widget;
-    boolvar = (gboolean*)g_object_get_data(G_OBJECT(check_button), "boolvar");
-    sensitive_widget = g_object_get_data(G_OBJECT(check_button), "sensitive_widget");
-    oldstate = *boolvar;
-    *boolvar = gtk_toggle_button_get_active(check_button);
-    if (sensitive_widget)
-        gtk_widget_set_sensitive(GTK_WIDGET(sensitive_widget), *boolvar);
-    if (boolvar == &(global->command.enabled)) {
-        gtk_widget_set_visible(global->menu_item, *boolvar);
-    } else if (oldstate != *boolvar)
-        setup_monitor(global);
+    setup_monitor(global);
 }
 
 static void
@@ -724,11 +698,10 @@ switch_cb(GtkSwitch *check_button, gboolean state, t_global_monitor *global)
     sensitive_widget = g_object_get_data(G_OBJECT(check_button), "sensitive_widget");
     oldstate = *boolvar;
     *boolvar = state;
+    gtk_switch_set_state (check_button, state);
     if (sensitive_widget)
-        gtk_widget_set_sensitive(GTK_WIDGET(sensitive_widget), *boolvar);
-    if (boolvar == &(global->command.enabled)) {
-        gtk_widget_set_visible(global->menu_item, *boolvar);
-    } else if (oldstate != *boolvar)
+        gtk_revealer_set_reveal_child (GTK_REVEALER (sensitive_widget), *boolvar);
+    if (oldstate != *boolvar)
         setup_monitor(global);
 }
 
@@ -742,7 +715,7 @@ color_set_cb(GtkColorButton *color_button, t_global_monitor *global)
 }
 
 static void
-monitor_dialog_response (GtkWidget *dlg, int response, 
+monitor_dialog_response (GtkWidget *dlg, int response,
                          t_global_monitor *global)
 {
     gtk_widget_destroy (dlg);
@@ -762,35 +735,29 @@ change_timeout_cb(GtkSpinButton *spin, t_global_monitor *global)
 static void
 change_timeout_seconds_cb(GtkSpinButton *spin, t_global_monitor *global)
 {
+    gboolean** use_timeout_seconds = (gboolean**)g_object_get_data (G_OBJECT(spin), "boolvar");
     global->timeout_seconds = gtk_spin_button_get_value(spin);
 
+    if (global->timeout_seconds == 0)
+        *use_timeout_seconds = (gboolean *) FALSE;
+    else
+        *use_timeout_seconds = (gboolean *) TRUE;
+
     setup_timer(global);
 }
 #endif
 
-/* Creates a switch box if boolvar is non-null, and its label.
- * If it is a check box, it will control the sensitivity of target.
- * If it is a label, its mnemonic will point to target.
+/* Creates a label, its mnemonic will point to target.
  * Returns the widget. */
-static GtkWidget *new_label_or_check_button(t_global_monitor *global,
-                                            GtkGrid *grid, guint row,
-                                            const gchar *labeltext,
-                                            gboolean *boolvar, GtkWidget *target)
+static GtkWidget *new_label (GtkGrid *grid, guint row,
+                             const gchar *labeltext, GtkWidget *target)
 {
-    GtkWidget *label, *sw;
-    if (boolvar) {
-        sw = gtk_switch_new();
-        g_object_set_data (G_OBJECT(sw), "sensitive_widget", target);
-        g_object_set_data (G_OBJECT(sw), "boolvar", boolvar);
-        gtk_switch_set_active (GTK_SWITCH(sw), *boolvar);
-        switch_cb (GTK_SWITCH(sw), *boolvar, global);
-        g_signal_connect (GTK_WIDGET(sw), "state-set",
-                          G_CALLBACK(switch_cb), global);
-        gtk_grid_attach(grid, sw, 2, row, 1, 1);
-    }
+    GtkWidget *label;
+
     label = gtk_label_new_with_mnemonic (labeltext);
-    gtk_widget_set_halign(label, GTK_ALIGN_END);
+    gtk_widget_set_halign(label, GTK_ALIGN_START);
     gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+    gtk_widget_set_margin_start (label, 12);
     gtk_label_set_mnemonic_widget(GTK_LABEL(label), target);
     gtk_grid_attach(grid, label, 0, row, 1, 1);
     return label;
@@ -801,12 +768,15 @@ static void new_monitor_setting(t_global_monitor *global, GtkGrid *grid, int pos
                            const gchar *title, gboolean *boolvar, GdkRGBA* colorvar,
                            gboolean * use_label, gchar **labeltext)
 {
-    GtkWidget *subgrid, *sw, *label, *button, *check, *entry;
+    GtkWidget *revealer, *subgrid, *sw, *label, *button, *entry;
     gchar *markup;
 
     sw = gtk_switch_new();
     g_object_set_data (G_OBJECT(sw), "boolvar", boolvar);
     gtk_switch_set_active (GTK_SWITCH(sw), *boolvar);
+    gtk_widget_set_halign (sw, GTK_ALIGN_END);
+    gtk_widget_set_valign (sw, GTK_ALIGN_CENTER);
+    gtk_widget_set_margin_top (sw, 12);
     switch_cb (GTK_SWITCH(sw), *boolvar, global);
     g_signal_connect (GTK_WIDGET(sw), "state-set",
                       G_CALLBACK(switch_cb), global);
@@ -815,84 +785,48 @@ static void new_monitor_setting(t_global_monitor *global, GtkGrid *grid, int pos
     label = gtk_label_new (markup);
     gtk_widget_set_halign(label, GTK_ALIGN_START);
     gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+    gtk_widget_set_margin_top (label, 12);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
     g_free (markup);
-    gtk_grid_attach(GTK_GRID(grid), label, 0, position, 2, 1);
-    gtk_grid_attach(GTK_GRID(grid), sw, 2, position, 1, 1);
+    gtk_grid_attach(GTK_GRID(grid), label, 0, position, 1, 1);
+    gtk_grid_attach(GTK_GRID(grid), sw, 1, position, 1, 1);
 
     if (colorvar == NULL)
         return;
+    revealer = gtk_revealer_new ();
     subgrid = gtk_grid_new ();
-    g_object_set_data (G_OBJECT(sw), "sensitive_widget", subgrid);
-    gtk_grid_attach(GTK_GRID(grid), subgrid, 0, position + 1, 2, 1);
+    gtk_container_add (GTK_CONTAINER (revealer), subgrid);
+    gtk_revealer_set_reveal_child (GTK_REVEALER (revealer), TRUE);
+    g_object_set_data (G_OBJECT(sw), "sensitive_widget", revealer);
+    gtk_grid_attach(GTK_GRID(grid), revealer, 0, position + 1, 2, 1);
     gtk_grid_set_column_spacing (GTK_GRID(subgrid), 12);
     gtk_grid_set_row_spacing (GTK_GRID(subgrid), 6);
 
+    label = gtk_label_new_with_mnemonic (_("Options:"));
+    gtk_widget_set_halign (label, GTK_ALIGN_START);
+    gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
+    gtk_widget_set_margin_start (label, 12);
+    gtk_label_set_mnemonic_widget (GTK_LABEL (label), button);
+    gtk_grid_attach (GTK_GRID(subgrid), label, 0, 0, 1, 1);
+
+    /* Entry for the optional monitor label */
+    entry = gtk_entry_new ();
+    gtk_widget_set_hexpand (entry, TRUE);
+    gtk_widget_set_margin_start (entry, 12);
+    g_object_set_data (G_OBJECT(entry), "charvar", labeltext);
+    g_object_set_data (G_OBJECT(entry), "boolvar", use_label);
+    gtk_entry_set_text (GTK_ENTRY(entry), *labeltext);
+    g_signal_connect (G_OBJECT(entry), "changed",
+    G_CALLBACK(entry_changed_cb), global);
+    gtk_grid_attach(GTK_GRID(subgrid), entry, 1, 0, 1, 1);
+
+    /* Colorbutton to set the progressbar color */
     button = gtk_color_button_new_with_rgba(colorvar);
+    gtk_widget_set_halign(button, GTK_ALIGN_START);
     g_object_set_data(G_OBJECT(button), "colorvar", colorvar);
     g_signal_connect(G_OBJECT(button), "color-set",
                  G_CALLBACK (color_set_cb), global);
-
-    label = gtk_label_new_with_mnemonic (_("Bar color:"));
-    gtk_widget_set_halign(label, GTK_ALIGN_END);
-    gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), button);
-
-    gtk_grid_attach(GTK_GRID(subgrid), label, 1, 1, 1, 1);
-    gtk_grid_attach(GTK_GRID(subgrid), button, 2, 1, 1, 1);
-
-    entry = gtk_entry_new ();
-    g_object_set_data (G_OBJECT(entry), "charvar", labeltext);
-    gtk_entry_set_text (GTK_ENTRY(entry), *labeltext);
-    g_signal_connect (G_OBJECT(entry), "changed",
-                      G_CALLBACK(entry_changed_cb), global);
-
-    label = gtk_label_new_with_mnemonic (_("Text to display:"));
-    gtk_widget_set_halign(label, GTK_ALIGN_END);
-    gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
-    gtk_label_set_mnemonic_widget(GTK_LABEL(label), entry);
-
-    check = gtk_check_button_new();
-    g_object_set_data (G_OBJECT(check), "sensitive_widget", entry);
-    g_object_set_data (G_OBJECT(check), "boolvar", use_label);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(check), *use_label);
-    check_button_cb (GTK_TOGGLE_BUTTON(check), global);
-    g_signal_connect (G_OBJECT(check), "toggled",
-                      G_CALLBACK(check_button_cb), global);
-
-    gtk_grid_attach(GTK_GRID(subgrid), check, 0, 0, 1, 1);
-    gtk_grid_attach(GTK_GRID(subgrid), label, 1, 0, 1, 1);
-    gtk_grid_attach(GTK_GRID(subgrid), entry, 2, 0, 1, 1);
-}
-
-/* Adds an entry box to the grid, optionally with a checkbox to enable it.
- * Set boolvar to NULL if you do not want a checkbox. */
-static void new_entry(t_global_monitor *global, GtkGrid *grid, guint row,
-                      const gchar *labeltext, gchar **charvar,
-                      gboolean *boolvar)
-{
-    GtkWidget *entry;
-    entry = gtk_entry_new ();
-    g_object_set_data (G_OBJECT(entry), "charvar", charvar);
-    gtk_entry_set_text (GTK_ENTRY(entry), *charvar);
-    g_signal_connect (G_OBJECT(entry), "changed",
-                      G_CALLBACK(entry_changed_cb), global);
-    new_label_or_check_button(global, GTK_GRID(grid), row, labeltext, boolvar, entry);
-    gtk_grid_attach(grid, entry, 1, row, 1, 1);
-}
-
-/* Adds a new spin button, optionally with a checkbox to enable it.
- * Set boolvar to NULL if you do not want a checkbox. */
-static void new_spin_button(t_global_monitor *global, GtkGrid *grid, guint row,
-                            const gchar *labeltext,
-                            gfloat value, gfloat min, gfloat max, gfloat step,
-                            GCallback callback, gboolean* boolvar) {
-    GtkWidget *button;
-    button = gtk_spin_button_new_with_range (min, max, step);
-    gtk_spin_button_set_value (GTK_SPIN_BUTTON (button), value);
-    g_signal_connect (G_OBJECT (button), "value-changed", callback, global);
-    new_label_or_check_button(global, grid, row, labeltext, boolvar, button);
-    gtk_grid_attach(grid, button, 1, row, 1, 1);
+    gtk_grid_attach(GTK_GRID(subgrid), button, 2, 0, 1, 1);
 }
 
 static void
@@ -900,7 +834,7 @@ monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *global)
 {
     GtkWidget           *dlg;
     GtkBox              *content;
-    GtkWidget           *grid;
+    GtkWidget           *grid, *label, *entry, *button;
     guint                count;
     t_monitor           *monitor;
     static const gchar *FRAME_TEXT[] = {
@@ -911,13 +845,13 @@ monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *global)
     };
 
     xfce_panel_plugin_block_menu (plugin);
-    
-    dlg = xfce_titled_dialog_new_with_buttons (_("System Load Monitor"), 
+
+    dlg = xfce_titled_dialog_new_with_buttons (_("System Load Monitor"),
                      GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (plugin))),
                                                GTK_DIALOG_DESTROY_WITH_PARENT,
                                                "gtk-close", GTK_RESPONSE_OK,
                                                NULL);
-    
+
     g_signal_connect (G_OBJECT (dlg), "response",
                       G_CALLBACK (monitor_dialog_response), global);
 
@@ -929,27 +863,54 @@ monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *global)
     grid = gtk_grid_new();
     gtk_grid_set_column_spacing (GTK_GRID(grid), 12);
     gtk_grid_set_row_spacing (GTK_GRID(grid), 6);
-    gtk_container_set_border_width(GTK_CONTAINER(grid), 6);
+    gtk_container_set_border_width(GTK_CONTAINER(grid), 12);
     gtk_box_pack_start (content, grid, TRUE, TRUE, 0);
-    new_spin_button(global, GTK_GRID(grid), 0,
-            _("Update interval:"),
-            (gfloat)global->timeout/1000.0, 0.100, 10.000, .050,
-            G_CALLBACK(change_timeout_cb), NULL);
+
+    label = gtk_label_new (NULL);
+    gtk_label_set_markup (GTK_LABEL (label), _("<b>General</b>"));
+    gtk_widget_set_halign(label, GTK_ALIGN_START);
+    gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+    gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1, 1);
+
+    /* Update interval */
+    button = gtk_spin_button_new_with_range (0.5, 10.0, .1);
+    gtk_label_set_mnemonic_widget (GTK_LABEL(label), button);
+    gtk_widget_set_halign (button, GTK_ALIGN_START);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (button), (gfloat)global->timeout/1000.0);
+    g_signal_connect (G_OBJECT (button), "value-changed", G_CALLBACK(change_timeout_cb), global);
+    gtk_grid_attach (GTK_GRID (grid), button, 1, 1, 1, 1);
+    new_label (GTK_GRID (grid), 1, _("Update interval:"), button);
+
 #ifdef HAVE_UPOWER_GLIB
-    new_spin_button(global, GTK_GRID(grid), 1,
-            _("Power-saving interval:"),
-            (gfloat)global->timeout_seconds, 1, 10, 1,
-            G_CALLBACK(change_timeout_seconds_cb),
-            &global->use_timeout_seconds);
+    /* Power-saving interval */
+    button = gtk_spin_button_new_with_range (0, 10, 1);
+    gtk_widget_set_halign (button, GTK_ALIGN_START);
+    gtk_widget_set_tooltip_text(GTK_WIDGET(button), _("Update interval when running on battery (uses regular update interval if set to zero)"));
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (button), (gfloat)global->timeout_seconds);
+    g_object_set_data (G_OBJECT(button), "boolvar", &global->use_timeout_seconds);
+    g_signal_connect (G_OBJECT (button), "value-changed", G_CALLBACK(change_timeout_seconds_cb), global);
+    gtk_grid_attach (GTK_GRID (grid), button, 1, 2, 1, 1);
+    new_label (GTK_GRID (grid), 2, _("Power-saving interval:"), button);
 #endif
-    new_entry(global, GTK_GRID(grid), 2,
-              _("System monitor:"),
-              &global->command.command_text, &global->command.enabled);
+
+    /* System Monitor */
+    entry = gtk_entry_new ();
+    gtk_widget_set_hexpand (entry, TRUE);
+    g_object_set_data (G_OBJECT(entry), "charvar", &global->command.command_text);
+    gtk_entry_set_text (GTK_ENTRY(entry), global->command.command_text);
+    g_object_set_data (G_OBJECT(entry), "boolvar", &global->command.enabled);
+    gtk_widget_set_tooltip_text(GTK_WIDGET(entry), _("Launched when clicking on the plugin"));
+    g_signal_connect (G_OBJECT(entry), "changed",
+                      G_CALLBACK(entry_changed_cb), global);
+    gtk_grid_attach (GTK_GRID (grid), entry, 1, 3, 1, 1);
+    label = new_label (GTK_GRID (grid), 3, _("System monitor:"), entry);
+
+    /* Add options for the three monitors */
     for(count = 0; count < 3; count++)
     {
         monitor = global->monitor[count];
 
-        new_monitor_setting(global, GTK_GRID(grid), 3 + 2 * count,
+        new_monitor_setting(global, GTK_GRID(grid), 4 + 2 * count,
                            _(FRAME_TEXT[count]),
                            &monitor->options.enabled,
                            &monitor->options.color,
@@ -957,11 +918,10 @@ monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *global)
                            &monitor->options.label_text);
     }
 
-    /*uptime monitor options - start*/
-    new_monitor_setting(global, GTK_GRID(grid), 10,
+    /* Uptime monitor options */
+    new_monitor_setting(global, GTK_GRID(grid), 11,
                       _(FRAME_TEXT[3]), &global->uptime->enabled,
                       NULL, NULL, NULL);
-    /*uptime monitor options - end*/
 
     gtk_widget_show_all (dlg);
 }
@@ -983,7 +943,7 @@ monitor_show_about(XfcePanelPlugin *plugin, t_global_monitor *global)
       "program-name", PACKAGE_NAME,
       "comments", _("Monitor CPU load, swap usage and memory footprint"),
       "website", "http://goodies.xfce.org/projects/panel-plugins/xfce4-systemload-plugin",
-      "copyright", _("Copyright (c) 2003-2017\n"),
+      "copyright", _("Copyright (c) 2003-2018\n"),
       "authors", auth, NULL);
 
    if(icon)
@@ -994,13 +954,13 @@ static void
 systemload_construct (XfcePanelPlugin *plugin)
 {
     t_global_monitor *global;
- 
+
     xfce_textdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
-    
+
     global = monitor_control_new (plugin);
 
     monitor_read_config (plugin, global);
-    
+
     create_monitor (global);
     monitor_set_mode (plugin,
                       xfce_panel_plugin_get_mode (plugin),
@@ -1023,10 +983,10 @@ systemload_construct (XfcePanelPlugin *plugin)
 #endif /* UP_CHECK_VERSION */
     }
 #endif /* HAVE_UPOWER_GLIB */
-    
+
     g_signal_connect (plugin, "free-data", G_CALLBACK (monitor_free), global);
 
-    g_signal_connect (plugin, "save", G_CALLBACK (monitor_write_config), 
+    g_signal_connect (plugin, "save", G_CALLBACK (monitor_write_config),
                       global);
 
     g_signal_connect (plugin, "size-changed", G_CALLBACK (monitor_set_size),
@@ -1038,13 +998,8 @@ systemload_construct (XfcePanelPlugin *plugin)
     g_signal_connect (plugin, "button-press-event", G_CALLBACK (click_event),
                       global);
 
-    xfce_panel_plugin_menu_insert_item (plugin, GTK_MENU_ITEM (global->menu_item));
-    g_signal_connect (GTK_MENU_ITEM(global->menu_item), "activate",
-                      G_CALLBACK (spawn_system_monitor), global);
-    gtk_widget_set_visible (global->menu_item, global->command.enabled);
-
     xfce_panel_plugin_menu_show_configure (plugin);
-    g_signal_connect (plugin, "configure-plugin", 
+    g_signal_connect (plugin, "configure-plugin",
                       G_CALLBACK (monitor_create_options), global);
 
     xfce_panel_plugin_menu_show_about(plugin);
@@ -1053,4 +1008,3 @@ systemload_construct (XfcePanelPlugin *plugin)
 }
 
 XFCE_PANEL_PLUGIN_REGISTER (systemload_construct);
-
